.. currentmodule:: sardana.tango

:mod:`~sardana.tango`
============================

.. automodule:: sardana.tango

.. rubric:: Modules

.. toctree::
    :maxdepth: 1
    
    core <tango/core>
    pool <tango/pool>
    macroserver <tango/macroserver>	
